@@ -1,12 +1,16 @@
+# -*- coding: utf-8 -*-
+
 import os
+import sys
 import logging
+import shutil
 
 from pyramid.config import Configurator
 from pyramid.httpexceptions import HTTPFound
 from pyramid.httpexceptions import HTTPNotFound
 from pyramid.session import UnencryptedCookieSessionFactoryConfig
 from pyramid.view import view_config
-
+from pyramid.response import Response
 from wsgiref.simple_server import make_server
 
 try:
@@ -19,6 +23,22 @@ try:
 except ImportError: # pragma: no cover
     pyramid_jinja2 = None
 
+
+# True if we are running on Python 3.
+PY3 = sys.version_info[0] == 3
+
+if PY3: # pragma: no cover
+    binary_type = bytes
+else:
+    binary_type = str
+
+def text_(s, encoding='latin-1', errors='strict'):
+    """ If ``s`` is an instance of ``binary_type``, return
+    ``s.decode(encoding, errors)``, otherwise return ``s``"""
+    if isinstance(s, binary_type):
+        return s.decode(encoding, errors)
+    return s # pragma: no cover
+
 logging.basicConfig(level=logging.NOTSET)
 log = logging.getLogger(__file__)
 
@@ -36,7 +56,7 @@ def notfound(request):
 def notfound_view(request):
     return {}
 
-@view_config(route_name='test_page', renderer='__main__:templates/index.mako')
+@view_config(renderer='__main__:templates/index.mako') # found via traversal
 def test_page(request):
     title = 'Pyramid Debugtoolbar'
     log.info(title)
@@ -47,7 +67,12 @@ def test_page(request):
 
 @view_config(route_name='test_redirect')
 def test_redirect(request):
-    return HTTPFound(location=request.route_url('test_page'))
+    return HTTPFound(location='/')
+
+@view_config(route_name='test_highorder',
+             renderer='__main__:templates/highorder.mako')
+def test_highorder(request):
+    return {}
 
 @view_config(route_name='test_predicates',
         renderer='__main__:templates/index.mako')
@@ -63,8 +88,19 @@ def test_predicates(request):
 def test_template_exc(request):
     return {'title':'Test template exceptions'}
 
+class DummyRootFactory(object):
+    def __init__(self, request):
+        self.request = request
+    def __getitem__(self, name):
+        return self
+
 if __name__ == '__main__':
     # configuration settings
+    try:
+        # ease testing py2 and py3 in same directory
+        shutil.rmtree(os.path.join(here, 'mako_modules'))
+    except:
+        pass
     settings = {}
     settings['debug_templates'] = True
     settings['reload_templates'] = True
@@ -75,9 +111,9 @@ if __name__ == '__main__':
     # session factory
     session_factory = UnencryptedCookieSessionFactoryConfig('itsaseekreet')
     # configuration setup
-    config = Configurator(settings=settings, session_factory=session_factory)
+    config = Configurator(settings=settings, session_factory=session_factory,
+                          root_factory=DummyRootFactory)
     # routes setup
-    config.add_route('test_page', '/')
     config.add_route('test_redirect', '/redirect')
     config.add_route('test_predicates', '/predicates', request_method='GET')
     config.add_route('test_exc', '/exc')
@@ -85,11 +121,13 @@ if __name__ == '__main__':
     config.add_route('test_chameleon_exc', '/chameleon_exc')
     config.add_route('test_mako_exc', '/mako_exc')
     config.add_route('test_jinja2_exc', '/jinja2_exc')
+    config.add_route('test_highorder', text_(b'/La Pe\xc3\xb1a', 'utf-8'))
     config.scan('__main__')
     if pyramid_jinja2:
         config.include('pyramid_jinja2')
     if sqlalchemy:
         config.include('sqla')
     config.include('pyramid_debugtoolbar')
-    httpd = make_server('', 8080, config.make_wsgi_app())
+    app = config.make_wsgi_app()
+    httpd = make_server('', 8080, app)
     httpd.serve_forever()
